==> lovecraftr_1.0.0.tar.gz: lovecraftr/R/lovecraft_stories.R <==
#' The text of H.P. Lovecraft's "At the Mountains of Madness"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "At the Mountains of Madness".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70652>
#' @format A character vector with 4618 elements
"mountain_madness"

#' The text of H.P. Lovecraft's "The Colour Out of Space"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Colour Out of Space".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68236>
#' @format A character vector with 1110 elements
"colour_space"

#' The text of H.P. Lovecraft's "The Shadow Over Innsmouth"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Shadow Over Innsmouth".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73181>
#' @format A character vector with 1708 elements
"shadow_innsmouth"

#' The text of H.P. Lovecraft's "The Shunned House"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Shunned House".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/31469>
#' @format A character vector with 1048 elements
"shunned_house"

#' The text of H.P. Lovecraft's "The Case of Charles Dexter Ward"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Case of Charles Dexter Ward".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73547>
#' @format A character vector with 4379 elements
"charles_dexter"

#' The text of H.P. Lovecraft's "The Horror at Red Hook"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Horror at Red Hook".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/72966>
#' @format A character vector with 873 elements
"red_hook"

#' The text of H.P. Lovecraft's "The Call of Cthulhu"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Call of Cthulhu".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68283>
#' @format A character vector with 1194 elements
"call_of_cthulhu"

#' The text of H.P. Lovecraft's "The Dunwich Horror"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Dunwich Horror".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/50133>
#' @format A character vector with 1694 elements
"dunwich_horror"


#' The text of H.P. Lovecraft's "Writings in the United Amateur"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Writings in the United Amateur".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/30637>
#' @format A character vector with 10749 elements
"united_amateur"


#' The text of H.P. Lovecraft's "The haunter of the dark"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The haunter of the dark".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73233>
#' @format A character vector with 954 elements
"haunter_dark"

#' The text of H.P. Lovecraft's "The thing on the door-step"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The thing on the door-step".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73230>
#' @format A character vector with 1081 elements
"door_step"


#' The text of H.P. Lovecraft's "The festival"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The festival".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68553>
#' @format A character vector with 345 elements
"festival"


#' The text of H.P. Lovecraft's "The lurking fear"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The lurking fear".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70486>
#' @format A character vector with 791 elements
"lurking"


#' The text of H.P. Lovecraft's "The silver key"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The silver key".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70478>
#' @format A character vector with 472 elements
"key"


#' The text of H.P. Lovecraft's "The quest of Iranon"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The quest of Iranon".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73182>
#' @format A character vector with 258 elements
"iranon"


#' The text of H.P. Lovecraft's "He"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "He".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68547>
#' @format A character vector with 419 elements
"he"


#' The text of H.P. Lovecraft's "Cool air"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Cool air".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73177>
#' @format A character vector with 339 elements
"air"

==> lovecraftr_1.2.0.tar.gz: lovecraftr/R/lovecraft_stories.R <==
#' The text of H.P. Lovecraft's "At the Mountains of Madness"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "At the Mountains of Madness".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70652>
#' @format A character vector with 4618 elements
"mountain_madness"

#' The text of H.P. Lovecraft's "The Colour Out of Space"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Colour Out of Space".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68236>
#' @format A character vector with 1110 elements
"colour_space"

#' The text of H.P. Lovecraft's "The Shadow Over Innsmouth"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Shadow Over Innsmouth".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73181>
#' @format A character vector with 1708 elements
"shadow_innsmouth"

#' The text of H.P. Lovecraft's "The Shunned House"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Shunned House".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/31469>
#' @format A character vector with 1048 elements
"shunned_house"

#' The text of H.P. Lovecraft's "The Case of Charles Dexter Ward"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Case of Charles Dexter Ward".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73547>
#' @format A character vector with 4379 elements
"charles_dexter"

#' The text of H.P. Lovecraft's "The Horror at Red Hook"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Horror at Red Hook".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/72966>
#' @format A character vector with 873 elements
"red_hook"

#' The text of H.P. Lovecraft's "The Call of Cthulhu"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Call of Cthulhu".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68283>
#' @format A character vector with 1194 elements
"call_of_cthulhu"

#' The text of H.P. Lovecraft's "The Dunwich Horror"
#'
#' A dataset containing the full text of H.P. Lovecraft's story
#' "The Dunwich Horror".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/50133>
#' @format A character vector with 1694 elements
"dunwich_horror"


#' The text of H.P. Lovecraft's "Writings in the United Amateur"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Writings in the United Amateur".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/30637>
#' @format A character vector with 10749 elements
"united_amateur"


#' The text of H.P. Lovecraft's "The haunter of the dark"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The haunter of the dark".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73233>
#' @format A character vector with 954 elements
"haunter_dark"

#' The text of H.P. Lovecraft's "The thing on the door-step"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The thing on the door-step".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73230>
#' @format A character vector with 1081 elements
"door_step"


#' The text of H.P. Lovecraft's "The festival"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The festival".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68553>
#' @format A character vector with 345 elements
"festival"


#' The text of H.P. Lovecraft's "The lurking fear"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The lurking fear".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70486>
#' @format A character vector with 791 elements
"lurking"


#' The text of H.P. Lovecraft's "The silver key"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The silver key".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/70478>
#' @format A character vector with 472 elements
"key"


#' The text of H.P. Lovecraft's "The quest of Iranon"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The quest of Iranon".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73182>
#' @format A character vector with 258 elements
"iranon"


#' The text of H.P. Lovecraft's "He"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "He".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/68547>
#' @format A character vector with 419 elements
"he"


#' The text of H.P. Lovecraft's "Cool air"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Cool air".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.gutenberg.org/ebooks/73177>
#' @format A character vector with 339 elements
"air"



#' The text of H.P. Lovecraft's "The Alchemist"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Alchemist".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/a.aspx>
#' @format A character vector with 223 elements
"alchemist"



#' The text of H.P. Lovecraft's "Azathoth"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Azathoth".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/az.aspx>
#' @format A character vector with 34 elements
"azathoth"



#' The text of H.P. Lovecraft's "The Beast in the Cave"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Beast in the Cave".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/bc.aspx>
#' @format A character vector with 153 elements
"beast_cave"


#' The text of H.P. Lovecraft's "Beyond the Wall of Sleep"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Beyond the Wall of Sleep".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/bws.aspx>
#' @format A character vector with 274 elements
"wall_sleep"



#' The text of H.P. Lovecraft's "The Book"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Book".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/b.aspx>
#' @format A character vector with 75 elements
"book"


#' The text of H.P. Lovecraft's "The Cats of Ulthar"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Cats of Ulthar".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/cu.aspx>
#' @format A character vector with 82 elements
"cats"


#' The text of H.P. Lovecraft's "Celephaïs"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Celephaïs".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/c.aspx>
#' @format A character vector with 153 elements
"celephais"

#' The text of H.P. Lovecraft's "Dagon"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Dagon".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/d.aspx>
#' @format A character vector with 133 elements
"dagon"

#' The text of H.P. Lovecraft's "The Descendant"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Descendant".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/de.aspx>
#' @format A character vector with 92 elements
"descendant"

#' The text of H.P. Lovecraft's "The Doom That Came to Sarnath"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Doom That Came to Sarnath".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/ds.aspx>
#' @format A character vector with 160 elements
"doom"

#' The text of H.P. Lovecraft's "The Dream-Quest of Unknown Kadath"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Dream-Quest of Unknown Kadath".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/dq.aspx>
#' @format A character vector with 2483 elements
"unknown_kadath"

#' The text of H.P. Lovecraft's "Herbert West—Reanimator"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "Herbert West—Reanimator".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/hwr.aspx>
#' @format A character vector with 739 elements
"reanimator"

#' The text of H.P. Lovecraft's "The Hound"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Hound".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/h.aspx>
#' @format A character vector with 189 elements
"hound"

#' The text of H.P. Lovecraft's "The Music of Erich Zann"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Music of Erich Zann".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/mez.aspx>
#' @format A character vector with 198 elements
"erich_zann"


#' The text of H.P. Lovecraft's "The Nameless City"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Nameless City".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/nc.aspx>
#' @format A character vector with 299 elements
"city"

#' The text of H.P. Lovecraft's "The Outsider"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Outsider".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/o.aspx>
#' @format A character vector with 211 elements
"outsider"


#' The text of H.P. Lovecraft's "The Shadow out of Time"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Shadow out of Time".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/sot.aspx>
#' @format A character vector with 1528 elements
"shadow_time"


#' The text of H.P. Lovecraft's "The Temple"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Temple".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/te.aspx>
#' @format A character vector with 319 elements
"temple"

#' The text of H.P. Lovecraft's "The Dreams in the Witch House"
#'
#' A dataset containing the full text of H.P. Lovecraft's
#' "The Dreams in the Witch House".
#' The text is provided as a character vector, with each element
#' representing a chunk of the full text.
#'
#' @source <https://www.hplovecraft.com/writings/texts/fiction/dwh.aspx>
#' @format A character vector with 892 elements
"witch_house"
